translate.storage.bundleprojstore

Package translate :: Package storage :: Module bundleprojstore |
[hide private]
[frames] | no frames]

# Module bundleprojstore

source code

Classes | [hide private]
| InvalidBundleError
| BundleProjectStore Represents a translate project bundle (zip archive).

Variables | [hide private]
| __package__ = ``'``translate.storage``'``

Imports: os, shutil, tempfile, ZipFile, ProjectStore, FileExistsInProjectError, FileNotInProjectError